<?php

/**
 * Mibooz Theme Customizer
 *
 * @package mibooz
 */


$mibooz_config_id = 'mibooz_customize';

Kirki::add_config($mibooz_config_id, array(
	'capability'    => 'edit_theme_options',
	'option_type'   => 'theme_mod',
));


/**
 * theme option panel master
 */

Kirki::add_panel('mibooz_theme_opt', array(
	'priority'    => 240,
	'title'       => esc_html__('Mibooz Options', 'mibooz'),
	'description' => esc_html__('Mibooz Theme options panel', 'mibooz'),
));

/**
 * General options
 */
Kirki::add_section('mibooz_theme_general', array(
	'title'          => esc_html__('General Settings', 'mibooz'),
	'description'    => esc_html__('Mibooz General Settings.', 'mibooz'),
	'panel'          => 'mibooz_theme_opt',
	'priority'       => 160,
));


// theme base color
Kirki::add_field($mibooz_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_base_color',
	'label'       => esc_html__('Select Theme Base color', 'mibooz'),
	'section'     => 'mibooz_theme_general',
	'default'     => sanitize_hex_color('#dd0429'),
]);


// theme black color
Kirki::add_field($mibooz_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_black_color',
	'label'       => esc_html__('Select Theme Black color', 'mibooz'),
	'section'     => 'mibooz_theme_general',
	'default'     => sanitize_hex_color('#0f0d1d'),
]);

// general options fields

Kirki::add_field($mibooz_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'preloader',
	'label'       => esc_html__('Preloader Visibility', 'mibooz'),
	'section'     => 'mibooz_theme_general',
	'default'     => false,
	'priority'    => 10
]);



Kirki::add_field($mibooz_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'scroll_to_top',
	'label'       => esc_html__('Back to top Visibility', 'mibooz'),
	'section'     => 'mibooz_theme_general',
	'default'     => false,
	'priority'    => 10
]);

Kirki::add_field($mibooz_config_id, [
	'type'        => 'select',
	'settings'    => 'scroll_to_top_icon',
	'label'       => esc_html__('Select Back to top icon', 'mibooz'),
	'section'     => 'mibooz_theme_general',
	'default'     => 'fa-angle-up',
	'priority'    => 10,
	'multiple'    => 0,
	'choices'     => mibooz_get_fa_icons(),
	'active_callback'  => function () {
		$switch_value = get_theme_mod('scroll_to_top', true);

		if (true === $switch_value) {
			return true;
		}
		return false;
	},
]);


// background image
Kirki::add_field($mibooz_config_id, [
	'type'        => 'image',
	'settings'    => 'preloader_image',
	'label'       => esc_html__('Custom Preloader Image', 'mibooz'),
	'section'     => 'mibooz_theme_general',
]);


// page header background image
Kirki::add_field($mibooz_config_id, [
	'type'        => 'image',
	'settings'    => 'page_header_bg_image',
	'label'       => esc_html__('Page Header Background Image', 'mibooz'),
	'section'     => 'mibooz_theme_general',
]);





/**
 * Header options
 */

Kirki::add_section('mibooz_theme_header', array(
	'title'          => esc_html__('Header Settings', 'mibooz'),
	'description'    => esc_html__('Mibooz Header Settings.', 'mibooz'),
	'panel'          => 'mibooz_theme_opt',
	'priority'       => 160,
));



// set logo width
Kirki::add_field($mibooz_config_id, [
	'type'        => 'text',
	'settings'    => 'header_logo_width',
	'label'       => esc_html__('Add Logo size in px', 'mibooz'),
	'section'     => 'mibooz_theme_header',
	'default'     => esc_html(198),
]);



// stricky switch
Kirki::add_field($mibooz_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'header_stricked_menu',
	'label'       => esc_html__('Stricky Header', 'mibooz'),
	'section'     => 'mibooz_theme_header',
	'description'    => esc_html__('If you are logged in and your top WordPress Admin bar is active this setting will not effect. But while logged out you will see your sticky menu is toggling by this', 'mibooz'),
	'default'     => true,
	'priority'    => 10,
]);


// header banner breadcrumb
Kirki::add_field($mibooz_config_id, [
	'type'        => 'switch',
	'settings'    => 'breadcrumb_opt',
	'label'       => esc_html__('Breadcrumb Visibility', 'mibooz'),
	'section'     => 'mibooz_theme_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'  => esc_html__('Enable', 'mibooz'),
		'off' => esc_html__('Disable', 'mibooz'),
	],
]);



// Footer options fields
Kirki::add_field($mibooz_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'header_custom',
	'label'       => esc_html__('Enable Custom Header', 'mibooz'),
	'section'     => 'mibooz_theme_header',
	'default'     => false,
	'priority'    => 10,
]);

// Get Footer Custom Post
Kirki::add_field($mibooz_config_id, [
	'type'        => 'select',
	'settings'    => 'header_custom_post',
	'label'       => esc_html__('Select Header Type', 'mibooz'),
	'choices'     => mibooz_post_query('header'),
	'section'     => 'mibooz_theme_header',
	'priority'    => 10,
	'active_callback' => function () {
		if (true == post_type_exists('header') && true == get_theme_mod('header_custom')) {
			return true;
		} else {
			return false;
		}
	},
]);


/**
 * Mobile Menu
 */

Kirki::add_section('mibooz_theme_mobile_menu', array(
	'title'          => esc_html__('Mobile Menu Settings', 'mibooz'),
	'description'    => esc_html__('Mibooz Mobile Menu Settings.', 'mibooz'),
	'panel'          => 'mibooz_theme_opt',
	'priority'       => 160,
));



Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'mibooz_mobile_menu_email',
	'label'    => esc_html__('Mobile Menu Email', 'mibooz'),
	'section'  => 'mibooz_theme_mobile_menu',
	'default'  => 'needhelp@mibooz.com',
	'priority' => 10,
]);

Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'mibooz_mobile_menu_phone',
	'label'    => esc_html__('Mobile Menu Phone', 'mibooz'),
	'section'  => 'mibooz_theme_mobile_menu',
	'default'  => '666 888 0000',
	'priority' => 10,
]);

Kirki::add_field($mibooz_config_id, [
	'type'        => 'repeater',
	'label'       => esc_html__('Select Social Icons', 'mibooz'),
	'section'     => 'mibooz_theme_mobile_menu',
	'priority'    => 10,
	'row_label' => [
		'type'  => 'text',
		'value' => esc_html__('Social Icons', 'mibooz'),
	],
	'button_label' => esc_html__('Add new Icon', 'mibooz'),
	'settings'     => 'mobile_menu_social_icons',
	'default'      => [
		[
			'link_icon' => 'fa-facebook',
			'link_url' => esc_url('http://facebook.com'),
		],
	],
	'fields' => [
		'link_icon'  => [
			'type'        => 'select',
			'label'       => esc_html__('Social Icon', 'mibooz'),
			'description' => esc_html__('Select Social Icons', 'mibooz'),
			'default'     => 'fa-facebook',
			'choices'     => mibooz_get_fa_icons(),
		],
		'link_url' => [
			'type'        => 'text',
			'label'       => esc_html__('Link Url', 'mibooz'),
			'description' => esc_html__('Add social profile links', 'mibooz'),
			'default'     => esc_url('https://facebook.com/'),
		],
	]
]);




/**
 * Footer options
 */

Kirki::add_section('mibooz_theme_footer', array(
	'title'          => esc_html__('Footer Settings', 'mibooz'),
	'description'    => esc_html__('Mibooz Footer Settings.', 'mibooz'),
	'panel'          => 'mibooz_theme_opt',
	'priority'       => 160,
));



Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'footer_copytext',
	'label'    => esc_html__('Text Control', 'mibooz'),
	'section'  => 'mibooz_theme_footer',
	'default'  => esc_html__('&copy; All right reserved', 'mibooz'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'mibooz_allowed_tags');;
	},
	'active_callback' => function () {
		if (false == get_theme_mod('footer_custom')) {
			return true;
		}
	},
]);


// Footer options fields
Kirki::add_field($mibooz_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'footer_custom',
	'label'       => esc_html__('Enable Custom Footer', 'mibooz'),
	'section'     => 'mibooz_theme_footer',
	'default'     => false,
	'priority'    => 10,
]);

// Get Footer Custom Post
Kirki::add_field($mibooz_config_id, [
	'type'        => 'select',
	'settings'    => 'footer_custom_post',
	'label'       => esc_html__('Select Footer Type', 'mibooz'),
	'choices'     => mibooz_post_query('footer'),
	'section'     => 'mibooz_theme_footer',
	'priority'    => 10,
	'active_callback' => function () {
		if (true == post_type_exists('footer') && true == get_theme_mod('footer_custom')) {
			return true;
		} else {
			return false;
		}
	},
]);




/**
 * Service Sidebar Menu
 */


Kirki::add_section('mibooz_theme_service_sidebar', array(
	'title'          => esc_html__('Service Sidebar Menu', 'mibooz'),
	'description'    => esc_html__('Mibooz Service Sidebar Options.', 'mibooz'),
	'panel'          => 'mibooz_theme_opt',
	'priority'       => 160,
	'active_callback' => function () {
		if (true == post_type_exists('service')) {
			return true;
		}
	},
));

Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'mibooz_sidebar_menu_title',
	'label'    => esc_html__('Menu Title', 'mibooz'),
	'section'  => 'mibooz_theme_service_sidebar',
	'default'  => esc_html__('All Services', 'mibooz'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'mibooz_allowed_tags');;
	},
]);


Kirki::add_field($mibooz_config_id, [
	'type'     => 'select',
	'settings' => 'mibooz_sidebar_menu_item',
	'label'    => esc_html__('Add Nav Menu', 'mibooz'),
	'section'  => 'mibooz_theme_service_sidebar',
	'priority' => 10,
	'choices'     => mibooz_get_nav_menu(),
]);

/**
 * Service Sidebar Contact
 */


Kirki::add_section('mibooz_theme_contact_sidebar', array(
	'title'          => esc_html__('Service Sidebar Contact', 'mibooz'),
	'description'    => esc_html__('Mibooz Service Sidebar Options.', 'mibooz'),
	'panel'          => 'mibooz_theme_opt',
	'priority'       => 160,
	'active_callback' => function () {
		if (true == post_type_exists('service')) {
			return true;
		}
	},
));

Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'mibooz_sidebar_contact_title',
	'label'    => esc_html__('Contact Title', 'mibooz'),
	'section'  => 'mibooz_theme_contact_sidebar',
	'default'  => esc_html__('Need Mibooz Help?', 'mibooz'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'mibooz_allowed_tags');;
	},
]);

Kirki::add_field($mibooz_config_id, [
	'type'     => 'textarea',
	'settings' => 'mibooz_sidebar_contact_text',
	'label'    => esc_html__('Contact Text', 'mibooz'),
	'section'  => 'mibooz_theme_contact_sidebar',
	'default'  => esc_html__('Default Text', 'mibooz'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'mibooz_allowed_tags');;
	},
]);

Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'mibooz_sidebar_contact_text',
	'label'    => esc_html__('Contact Text', 'mibooz'),
	'section'  => 'mibooz_theme_contact_sidebar',
	'default'  => esc_html__('Call us Anytime', 'mibooz'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'mibooz_allowed_tags');;
	},
]);

Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'mibooz_sidebar_contact_number',
	'label'    => esc_html__('Contact Number', 'mibooz'),
	'section'  => 'mibooz_theme_contact_sidebar',
	'default'  => esc_html__('666 888 000', 'mibooz'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'mibooz_allowed_tags');;
	},
]);

Kirki::add_field($mibooz_config_id, [
	'type'     => 'text',
	'settings' => 'mibooz_sidebar_contact_number_link',
	'label'    => esc_html__('Contact Number Link', 'mibooz'),
	'section'  => 'mibooz_theme_contact_sidebar',
	'default'  => esc_html__('#', 'mibooz'),
	'priority' => 10,
]);

// background image
Kirki::add_field($mibooz_config_id, [
	'type'        => 'image',
	'settings'    => 'mibooz_contact_sidebar_image',
	'label'       => esc_html__('Background Image', 'mibooz'),
	'section'     => 'mibooz_theme_contact_sidebar',
]);
